**************************************
ASDF - Advanced Scientific Data Format
**************************************

`asdf` is a tool for reading and writing Advanced Scientific Data
Format (ASDF) files.

.. include:: ../README.rst
    :start-after: begin-summary-text:
    :end-before: end-summary-text:

.. note::

    This is the **A**\ dvanced **S**\ cientific **D**\ ata **F**\ ormat - if
    you are looking for the
    **A**\ daptable **S**\ eismic **D**\ ata **F**\ ormat,
    go here: http://seismic-data.org/

Getting Started
===============

.. toctree::
   :maxdepth: 2

   asdf/install
   asdf/overview
   asdf/features
   asdf/config
   asdf/asdf_tool
   asdf/changes

.. _extending:

Extending ASDF
==============

.. toctree::
  :maxdepth: 2

  asdf/extending/use_cases
  asdf/extending/uris
  asdf/extending/schemas
  asdf/extending/resources
  asdf/extending/converters
  asdf/extending/extensions
  asdf/extending/manifests
  asdf/extending/compressors
  asdf/extending/legacy

API Documentation
=================

.. toctree::
  :maxdepth: 1

  asdf/user_api
  asdf/developer_api

Developer Overview
==================

Currently a work in progress. Intended to give an overview of how the various
parts of ASDF interact and which modules do what and how.

.. toctree::
  :maxdepth: 1

  asdf/developer_overview
  asdf/developer_versioning

Contributing and reporting issues
=================================

We welcome feedback and contributions of all kinds. Contributions of code,
documentation, or general feedback are all appreciated.

Feature requests and bug reports for the Python implementation can be posted at
`asdf's github page <https://github.com/asdf-format/asdf>`_.

The ASDF Standard itself also has a repository on github. Suggestions for
improvements to the ASDF Standard can be reported `here
<https://github.com/asdf-format/asdf-standard>`_.

See also
========

- The `Advanced Scientific Data Format (ASDF) standard
  <https://asdf-standard.readthedocs.io/>`__

- `asdf` Python package distribution on `pypi <https://pypi.org/project/asdf/>`_

Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
